{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "GATK HaplotypeCaller",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK-3.5.jar",
                "-T",
                "HaplotypeCaller"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "${ if (inputs.intervals.length == 1 && inputs.intervals[0].match(/^[0-9A-Za-z]+$/)) { return inputs.intervals[0] + \".g.vcf.gz\"; } else { return \"output.g.vcf.gz\"; } }"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-contamination",
                        "position": 7
                    },
                    "id": "#gatk_haplotypecaller.cwl/contamination_fraction"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--dbsnp",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-ERC",
                        "position": 3
                    },
                    "id": "#gatk_haplotypecaller.cwl/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GQB"
                        }
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#gatk_haplotypecaller.cwl/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#gatk_haplotypecaller.cwl/intervals"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#gatk_haplotypecaller.cwl/reference"
                }
            ],
            "id": "#gatk_haplotypecaller.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.g.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/gvcf"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "scatter GATK HaplotypeCaller over intervals",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/contamination_fraction"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#main/cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "id": "#main/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "id": "#main/intervals"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/haplotype_caller/gvcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/gvcf"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#main/haplotype_caller/intervals"
                    ],
                    "run": "#gatk_haplotypecaller.cwl",
                    "in": [
                        {
                            "source": "#main/contamination_fraction",
                            "id": "#main/haplotype_caller/contamination_fraction"
                        },
                        {
                            "source": "#main/cram",
                            "id": "#main/haplotype_caller/cram"
                        },
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/haplotype_caller/dbsnp_vcf"
                        },
                        {
                            "source": "#main/emit_reference_confidence",
                            "id": "#main/haplotype_caller/emit_reference_confidence"
                        },
                        {
                            "source": "#main/gvcf_gq_bands",
                            "id": "#main/haplotype_caller/gvcf_gq_bands"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/haplotype_caller/intervals"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/haplotype_caller/reference"
                        }
                    ],
                    "out": [
                        "#main/haplotype_caller/gvcf"
                    ],
                    "id": "#main/haplotype_caller"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
